%Title : analyse_IR
%Author: Bertrand Schyns
%Script to analyse the data from the IR frame in a steady state case

%Input: number of the IR image to analyse
function [Channel,y_up_border] = analyse_IR(z)
a = sprintf('Ir_image%u',z);
load(a)

% figure
% pcolor(Frame)
% colormap jet;
% title('Global view of the image')


%A first reduction of the matrix is done using the inlet and outlet
%position of the channel
Frame_r = Frame(90:120,39:291);
[y_size, x_size] = size(Frame_r);


%% Defining the chanel position
%Find the maximum in the matrix
T_max = max(max(Frame_r));
x_Tmax = find(Frame_r==T_max);
y_Tmax = mod(x_Tmax,y_size);
x_Tmax = (x_Tmax - y_Tmax)/y_size + 1;
x_Tmax = x_Tmax(1);
y_Tmax = y_Tmax(1);


%As the channel is not perfectly straight in the IR image, the limits of
%the channel are evolving along the axis. We will make the assumption
%that, being symetric, the two points marking the boundaries should be the
%two with the closest temperatures from one another while being at the
%given distance of the width of the channel. The first boundary to be
%looked at is the one correspding to the cross section where the maximum
%temeprature occurs.

width_px = 12;
dy = 1000; %Starting value at 1000 to be sure that the first value is accepted
y_border_max = 0;
for j = 0:width_px-1
    if dy > abs((Frame_r(y_Tmax+j,x_Tmax) - Frame_r(y_Tmax+j-width_px,x_Tmax)))
        dy =  abs(Frame_r(y_Tmax+j,x_Tmax) - Frame_r(y_Tmax+j-width_px,x_Tmax));
        y_border_max = j+y_Tmax; %Position of the uper boundary at the max temperature level
    end
end
y_mid_max = y_border_max - floor(width_px/2);

%The same approach is followed all along the channel

dy = zeros(length(Frame_r)-9,1);
y_up_border = zeros(length(Frame_r)-9,1);
y_down_border = zeros(length(Frame_r)-9,1);
y_mid = zeros(length(Frame_r)-9,1);
y_mid(1) = y_mid_max;
Channel = zeros(width_px,length(Frame_r));
for i = 1:length(dy)
    dy(i) = 1000;
    for j = 1:width_px-1
        if dy(i) > abs((Frame_r(y_mid(i)+j,1+5+i-1) - Frame_r(y_mid(i)+j-width_px,1+5+i-1)))
            dy(i) =  abs((Frame_r(y_mid(i)+j,1+5+i-1) - Frame_r(y_mid(i)+j-width_px,1+5+i-1)));
            y_up_border(i) = j+y_mid(i);%Position of the uper boundary at the max temperature level
        end
    end
    y_down_border(i) = y_up_border(i) - width_px + 1;
    y_mid(i) = y_up_border(i) - floor(width_px/2);%Update of the actual mid point.
    y_mid(i+1) = y_mid(i); %First guess for the next point.
    Channel(:,6+i-1) = Frame_r(y_down_border(i):y_up_border(i),1+5+i-1);
end


%As the borders at the inlet and outlet are not sraigth, the last few
%pixels are chosen starting from the closest one determined with the loop
%and using the geometry to be as close to the shape of the geometry as
%possible
for i = 1:5
    if i == 1
        Channel(4:9,i) = Frame_r(y_down_border(1)+3:y_up_border(1)-3,1+i-1);
        Channel(4:9,end-i+1) = Frame_r(y_down_border(end)+3:y_up_border(end)-3,end-i+1);
     elseif i==2 || i == 3
         Channel(3:10,i) = Frame_r(y_down_border(1)+2:y_up_border(1)-2,1+i-1);
         Channel(3:10,end-i+1) = Frame_r(y_down_border(end)+2:y_up_border(end)-2,end-i+1);
    else
         Channel(2:11,i) = Frame_r(y_down_border(1)+1:y_up_border(1)-1,1+i-1);
         Channel(2:11,end-i+1) = Frame_r(y_down_border(end)+1:y_up_border(end)-1,end-i+1);
    end
    
end


end

