%This function compute the upper and lower uncertainty error over the
%computation of the heat generated depending on the temperature measured by
%the camera (T_IR), the current I and the electrical resistivity rho_e of the
%inconel with their respective error. The other inputs are the length of
%the element dy, the cross section A_cross and the heat generated in that
%element E_gen.
function [dE_gen_up, dE_gen_down] = uncertainty_E_gen(I,T_IR,rho_e,dy,A_cross,Inconel_rho_e,E_gen)
%Error of the current generator
error_I = 0.01*I;
%Error of the IR camera
if T_IR > 100
    error_IR_T = 0.02*T_IR;
else
    error_IR_T = 2;
end

%Difference between the value and the minimal value possible with the
%different error commited
T_up = T_IR+error_IR_T;
position = floor(T_up);
diff = T_up - position;
rho_e_up = Inconel_rho_e(position) + diff*(Inconel_rho_e(position+1) - Inconel_rho_e(position));

d_rho_up = I^2 * dy * rho_e_up / A_cross - E_gen;
d_I_up = (I+error_I)^2 * dy* rho_e / A_cross - E_gen;
dE_gen_up = sqrt(d_rho_up^2 + d_I_up^2);

%Difference between the value and the minimal value possible with the
%different error commited
T_down = T_IR-error_IR_T;
position = floor(T_down);
diff = T_down - position;
rho_e_down = Inconel_rho_e(position) + diff*(Inconel_rho_e(position+1) - Inconel_rho_e(position));

d_rho_down = I^2 * dy * rho_e_down / A_cross - E_gen;
d_I_down = (I-error_I)^2 * dy * rho_e / A_cross - E_gen;
dE_gen_down = sqrt(d_rho_down^2 + d_I_down^2);
end