%This function compute the upper and lower uncertainty error over the
%computation of the heat transfer coefficient using the Dittus-Boeleter
%correlation in convection. The error depends on the bulk fluid temeprature
%T_F ( and its errors  dT_F), the absolute pressure P_sCO2, the mass flux
%G_chan and the hydraulic diameter.
function [dalpha_up,dalpha_down] = uncertainty_alpha(T_F,dT_F_up,dT_F_down,P_sCO2,G_chan,D_h,alpha_gn,fluid)
    error_P =  20000; %absolute uncertainty of the pressure transducer
    error_G = 15.6732 + 0.001*G_chan;
    
    mu = CoolProp.PropsSI('V', 'T', T_F, 'P', P_sCO2, fluid);             %Viscosity
    Pr = CoolProp.PropsSI('Prandtl', 'T', T_F, 'P', P_sCO2, fluid);                  %Prandtl number
    k = CoolProp.PropsSI('conductivity', 'T', T_F, 'P', P_sCO2, fluid);		%Conductivity of the fluid
    %Re_b = (G_chan*D_h)/mu;                                                       %Reynolds number

    
    %% dalpha_up
    %T_F impact
    mu_T_F_up = CoolProp.PropsSI('V', 'T', T_F + dT_F_up , 'P', P_sCO2, fluid);
    Re_b_T_F_up = (G_chan*D_h)/mu_T_F_up; 
    Pr_T_F_up = CoolProp.PropsSI('Prandtl', 'T', T_F  + dT_F_up, 'P', P_sCO2, fluid); 
    k_T_F_up = CoolProp.PropsSI('conductivity', 'T', T_F + dT_F_up, 'P', P_sCO2, fluid);
    Nuss_gn_T_F_up = 0.023*Re_b_T_F_up^0.8*Pr_T_F_up^0.4 * 0.91;
    d_T_F_up = (Nuss_gn_T_F_up*k_T_F_up)/D_h - alpha_gn;
    
    
    %pressure impact
    mu_P_up = CoolProp.PropsSI('V', 'T', T_F, 'P', P_sCO2 + error_P, fluid);            
    Pr_P_up = CoolProp.PropsSI('Prandtl', 'T', T_F, 'P', P_sCO2 + error_P, fluid);          
    k_P_up = CoolProp.PropsSI('conductivity', 'T', T_F, 'P', P_sCO2 + error_P, fluid);		
    Re_b_P_up = (G_chan*D_h)/mu_P_up;                                                      
    Nuss_gn_P_up = 0.023*Re_b_P_up^0.8*Pr_P_up^0.4 * 0.91;
    d_P_up = (Nuss_gn_P_up*k_P_up)/D_h - alpha_gn;
    
    
    %G impact
    Re_b_G_up = ((G_chan+error_G)*D_h)/mu;                                                      
    Nuss_gn_G_up = 0.023*Re_b_G_up^0.8*Pr^0.4 * 0.91;
    d_G_up = (Nuss_gn_G_up*k)/D_h - alpha_gn;
    
    dalpha_up = sqrt(d_T_F_up^2 + d_P_up^2 + d_G_up^2);%+ d_T_av_up^2 
    
    
    %% dalpha_down
    %T_F impact
    mu_T_F_down = CoolProp.PropsSI('V', 'T', T_F - dT_F_down , 'P', P_sCO2, fluid);
    Re_b_T_F_down = (G_chan*D_h)/mu_T_F_down; 
    Pr_T_F_down = CoolProp.PropsSI('Prandtl', 'T', T_F - dT_F_down , 'P', P_sCO2, fluid); 
    k_T_F_down = CoolProp.PropsSI('conductivity', 'T', T_F - dT_F_down, 'P', P_sCO2, fluid);
    Nuss_gn_T_F_down = 0.023*Re_b_T_F_down^0.8*Pr_T_F_down^0.4 * 0.91;
    d_T_F_down = (Nuss_gn_T_F_down*k_T_F_down)/D_h - alpha_gn;
   
    %pressure impact
    mu_P_down = CoolProp.PropsSI('V', 'T', T_F, 'P', P_sCO2 - error_P, fluid);            
    Pr_P_down = CoolProp.PropsSI('Prandtl', 'T', T_F, 'P', P_sCO2 - error_P, fluid);          
    k_P_down = CoolProp.PropsSI('conductivity', 'T', T_F, 'P', P_sCO2 - error_P, fluid);		
    Re_b_P_down = (G_chan*D_h)/mu_P_down;                                                      
    Nuss_gn_P_down = 0.023*Re_b_P_down^0.8*Pr_P_down^0.4 * 0.91;
    d_P_down = (Nuss_gn_P_down*k_P_down)/D_h - alpha_gn;
    
    
    %G impact
    Re_b_G_down = ((G_chan-error_G)*D_h)/mu;                                                      
    Nuss_gn_G_down = 0.023*Re_b_G_down^0.8*Pr^0.4 * 0.91;
    d_G_down = (Nuss_gn_G_down*k)/D_h - alpha_gn;
    
    dalpha_down = sqrt(d_T_F_down^2 + d_P_down^2 + d_G_down^2);% d_T_av_down^2 +
end