%This function compute the upper and lower uncertainty error over the
%computation of the fluid enthalpy depending on the mass flow m_dot, the
%enthalpy of the node h and of the previous node h0 (with its errors dh),
%the heat generated under the channel E_gen (with its errors dE_gen) and under the
%side wall E_gen_sw (with its errors dE_gen_sw) and finally the heat
%exchanged by radiation q_rad (with its errors dq_rad)
function [dh_up, dh_down] = uncertainty_h(m_dot,h,h0,dh_up0,dh_down0,E_gen,dE_gen_up,dE_gen_down,E_gen_sw,dE_gen_sw_up,dE_gen_sw_down,q_rad,dq_rad_up,dq_rad_down)
error_m_dot = 5.4167e-05 + 0.001*m_dot;

%dh_up calculation
d_m_dot_up = ((m_dot+error_m_dot) * h0 + sum(E_gen) + E_gen_sw*4/3 - sum(q_rad) )/(m_dot+error_m_dot) - h;
d_h0_up = (m_dot * (h0+dh_up0) + sum(E_gen) + E_gen_sw*4/3 - sum(q_rad) )/m_dot - h;
d_E_gen_up = zeros(1,length(E_gen));
d_E_gen_up_tot = 0;
for i = 1:length(E_gen)
    d_E_gen_up(i) = (m_dot * h0 + sum(E_gen) + dE_gen_up(i) + E_gen_sw*4/3 - sum(q_rad) )/m_dot - h;
    d_E_gen_up_tot = d_E_gen_up_tot + d_E_gen_up(i)^2;
end

d_E_gen_sw_up = (m_dot * h0 + sum(E_gen) + (E_gen_sw+dE_gen_sw_up)*4/3 - sum(q_rad) )/m_dot - h;
d_q_rad_up = zeros(1,length(q_rad));
d_q_rad_up_tot = 0;
for i = 1:length(q_rad)
    d_q_rad_up(i) = (m_dot * h0 + sum(E_gen)+ E_gen_sw*4/3 - sum(q_rad) - dq_rad_up(i) )/m_dot - h;
    d_q_rad_up_tot = d_q_rad_up_tot + d_q_rad_up(i)^2;
end

dh_up = sqrt(d_m_dot_up^2 + d_h0_up^2 + d_E_gen_up_tot + d_E_gen_sw_up^2 + d_q_rad_up_tot);


%dh_down calculation
d_m_dot_down = ((m_dot-error_m_dot) * h0 + sum(E_gen) + E_gen_sw*4/3 - sum(q_rad) )/(m_dot-error_m_dot) - h;
d_h0_down = (m_dot * (h0-dh_down0) + sum(E_gen) + E_gen_sw*4/3 - sum(q_rad) )/m_dot - h;
d_E_gen_down = zeros(1,length(E_gen));
d_E_gen_down_tot = 0;
for i = 1:length(E_gen)
    d_E_gen_down(i) = (m_dot * h0 + sum(E_gen) - dE_gen_down(i) + E_gen_sw*4/3 - sum(q_rad) )/m_dot - h;
    d_E_gen_down_tot = d_E_gen_down_tot + d_E_gen_down(i)^2;
end

d_E_gen_sw_down = (m_dot * h0 + sum(E_gen) + (E_gen_sw-dE_gen_sw_down)*4/3 - sum(q_rad) )/m_dot - h;
d_q_rad_down = zeros(1,length(q_rad));
d_q_rad_down_tot = 0;
for i = 1:length(q_rad)
    d_q_rad_down(i) = (m_dot * h0 + sum(E_gen)+ E_gen_sw*4/3 - sum(q_rad) + dq_rad_down(i) )/m_dot - h;
    d_q_rad_down_tot = d_q_rad_down_tot + d_q_rad_down(i)^2;
end

dh_down = sqrt(d_m_dot_down^2 + d_h0_down^2 + d_E_gen_down_tot + d_E_gen_sw_down^2 + d_q_rad_down_tot);

end