%Title : Convective analysis
%Author: Bertrand Schyns
%Model of analysis of the IR camera data in additioon to the LabView data of
%the corresponding test.

clc
clear all
%run analyse_IR to get the temperature of the Inconnel sheet from the
%average temperature of 5 IR images
T_frame = zeros(8,243,5);
for i = 1:5
    T_channel = analyse_IR(1,i);
    T_frame(:,:,i) = fliplr(T_channel(3:10,6:248));%The borders of the view port are removed as theview bord is longer and wider than the actual channel
end
size_chan = size(T_frame);
for i = 1:size_chan(1)
    for j = 1:size_chan(2)
        T_m(i,j) = mean(T_frame(i,j,:));
    end
end

Frame = '35.6Amp_0.986V_ssxlsx' %Name of the LabView data file
%% 
%Loading the Inconel properties that will be needed to compute the
%cnduction and the heat production. Those values were calculated using EES
%and will be interpolated later on. The units used are kg/K/Pa/J like
%Coolprop. The temperature goes from 1 to 200C with a 1C step.
Inconel_props = xlsread('Inconel_prop.xlsx', 'A2:C202');
Inconel_props = Inconel_props';
Inconel_T = Inconel_props(1,:);
Inconel_k = Inconel_props(2,:);
Inconel_rho_e = Inconel_props(3,:);

%% 
%Geometrical properties and problem specification
Th_B=254*10^(-6);                        %Thickness of the bottom Inconel 718sheet (micron to m)
L_B= 50*10^(-3);                         %Length of the bottom Inconel 718 sheet(mm to m) seen by the camera in the gap /!\ask Saad for actual dimension
W_ch= 1.92*10^(-3);                         %Width of the flow channel (mm to m) 
Th_SW=1.5*10^(-3);                       %Width of the wall seperating the channels (mm to m)
Th_SE=1.5*10^(-3);                       %Width of the side edge used for bonding the Inconel 718 to Macor (mm to m)
N_ch=3;                                  %Number of channel
R_a= 0.78*10^(-6);                          %Absolute roughness of the channel walls (micron to m)
W_header = N_ch*W_ch+Th_SW*(N_ch-1)+2*Th_SE;%Width of the header at the inlet and outlet
L_header = 7*10^(-3);                    %Length of the header region at the inlet and outlet
 
%Flow channel hydraulic diameter
H_ch= 600*10^(-6);                       %Height of the flow channels (micron to m)
A_cross_flow = H_ch*W_ch;                %Flow cross sectional area
per= 2*(H_ch+W_ch);                      %Perimeter
D_h= (4*A_cross_flow)/per;               %Hydraulic diamter

%Flow conditions
fluid = 'CO2';
%All data from Labview. The usefull columns are here :
%3.Inlet temperature [C] 4.Outlet temperature [C] 7.Inlet pressure [Psi]
%10.Mass flow rate [kg/h]
flow_data = xlsread(Frame,'data');
P_sCO2_psi= mean(flow_data(:,18));                        %Absolute pressure in the test section in psi
P_sCO2 =convpres(P_sCO2_psi,'psi','Pa'); %Absolute pressure in the test section in Pa
P_sCO2_bar= P_sCO2/10^5;                 %Absolute pressure in the test section in bar
G_chan = mean(flow_data(:,10))/(3*A_cross_flow*3600); %Mass flux in the test section [kg/m^2-s]
m_dot_chan= G_chan*A_cross_flow;         %Mass flow rate in a single channel [kg/s]
m_dot_total=m_dot_chan*N_ch;             %Total mass flow rate through the test section
G_total=G_chan;
T_F_in = mean(flow_data(:,3));       %Inlet temperature [C] "! Change it by the temperature of the actual temperature at the start of the vision gap using an energy balance over the first mm of the inlet"
h_F_in = CoolProp.PropsSI('H', 'T', T_F_in+273.15, 'P', P_sCO2, fluid);  %[J/kg]
[dh_F_in_up,dh_F_in_down] = uncertainty_h_F(T_F_in,h_F_in,P_sCO2,fluid);

T_F_out = mean(flow_data(:,4));
h_F_out = CoolProp.PropsSI('H', 'T', T_F_out+273.15, 'P', P_sCO2, fluid);
[dh_F_out_up,dh_F_out_down] = uncertainty_h_F(T_F_out,h_F_out,P_sCO2,fluid);


Delta_P_H2O = mean(flow_data(:,17));
Delta_kPa =Delta_P_H2O*0.2491; %Conversion from inch H2O to kPa

%Defining the pseudo-critical temperature
T_PC= -122.6+6.124*P_sCO2_bar-0.1657*P_sCO2_bar^2+0.01773*P_sCO2_bar^(2.5)-0.0005608*P_sCO2_bar^3;  %Pseudo-critical temperature - Liao and Zhao (2002) [C]


%Current
I_curr=mean(xlsread(Frame,'current'));                          %Current through the test section [Amp]	
 
W_total = (2*Th_SE)+(N_ch-1)*Th_SW+N_ch*W_ch;	%Total width of the test section
A_cross_total = W_total*Th_B;            %Total cross sectional area for current flow
I_density= I_curr/A_cross_total;

%Segmenting the model in the third dimension
N_nodes = size(T_m,2);                            %Number of nodes in the bottom portion of the test section
N_nodes_cross = size(T_m,1);                      %Number of node accros the channel"
L_begin = 0;                             %Left edge of the test section [m]
dy= L_B/(N_nodes);                      %Length of a nodes along the y axis (flow direction)
dx = W_ch/(N_nodes_cross);                 %Width of a node along the x axis (perpendicular to the flow direction)

%Assigning the position to the nodes
L_ax = zeros(1,length(N_nodes));
for i= 1:N_nodes
 L_ax(i)= L_begin+ dy *(i-1);
end
A_cross = dx*Th_B;
I_elem = I_density * A_cross;           %Current flowing through a single element
V_elem = A_cross*dy;

%Radiation
epsilon=0.95;                            %emissivity
sigma = 5.670374419*10^(-8);             %Stefan Boltzmann constant [W/m^2.K^4]
T_inf = 23;                              %Room temperature [C]


%%
%Boundary conditions
%The fluid temperature is considered uniform accros the width of the channel
T_F = zeros(1,length(N_nodes));         %Fluid temperature
h_F = zeros(1,length(N_nodes));         %Fluid enthalpy
dh_F_up = zeros(1,length(N_nodes));     %Upper error on the enthalpy of the fluid due to the different measurement errors
dh_F_down = zeros(1,length(N_nodes));   %Lower error on the enthalpy of the fluid due to the different measurement errors
dT_F_up = zeros(1,length(N_nodes));     %Upper error on the temperature of the fluid due to the different measurement errors
dT_F_down = zeros(1,length(N_nodes));   %Lower error on the temperature of the fluid due to the different measurement errors


%On the side, a constant heat flux is considered with the heat flux equal
%to half of the heat produced between the two channel under the side wall.
I_sw = I_density * Th_SW * Th_B ;
E_gen_sw = zeros(1,length(N_nodes));      %Heat flux equal at both side, the only difference along the channel is the electric resistivity
E_gen = zeros(N_nodes_cross,N_nodes);     %Heat generated in the Inconel
k = zeros(N_nodes_cross,N_nodes);         %Conductivity of the Inconel at every node
rho_e = zeros(N_nodes_cross,N_nodes);   %Electrical conductivity of the Inconel at every node
dE_gen_sw_up = zeros(1,N_nodes); %Upper error on the energy generated due to the different measurement errors
dE_gen_sw_down = zeros(1,N_nodes); %Lower error on the energy generated due to the different measurement errors
dE_gen_up = zeros(N_nodes_cross,N_nodes); %Upper error on the energy generated due to the different measurement errors
dE_gen_down = zeros(N_nodes_cross,N_nodes); %Lower error on the energy generated due to the different measurement errors


for i = 1:N_nodes
    position_sw = floor(T_m(1,i)+10);    
    %+10 is there to represent the fact that the temperature in the side
    %wall will be generally higher as it is not directly cooled down   
    diff_sw = T_m(1,i) +10 - position_sw; 
    rho_e_sw = Inconel_rho_e(position_sw) + diff_sw*(Inconel_rho_e(position_sw+1) - Inconel_rho_e(position_sw));
    E_gen_sw(i) = I_sw^2 * dy * rho_e_sw / (Th_SW * Th_B);
    [dE_gen_sw_up(i), dE_gen_sw_down(i)] = uncertainty_E_gen(I_sw,T_m(1,i)+10,rho_e_sw,dy,Th_SW * Th_B,Inconel_rho_e,E_gen_sw(i));
    for j = 1:N_nodes_cross
        position = floor(T_m(j,i));
        diff = T_m(j,i) - position;
        k(j,i) = Inconel_k(position) + diff*(Inconel_k(position+1) - Inconel_k(position));
        rho_e(j,i) = Inconel_rho_e(position) + diff*(Inconel_rho_e(position+1) - Inconel_rho_e(position));
        E_gen(j,i) = I_elem^2 * dy * rho_e(j,i) / A_cross;
        [dE_gen_up(j,i), dE_gen_down(j,i)] = uncertainty_E_gen(I_elem,T_m(j,i),rho_e(j,i),dy,A_cross,Inconel_rho_e,E_gen(j,i));
    end
end
E_gen_header_in = I_curr^2 * L_header * mean(rho_e(:,1))/(Th_B*W_header);
[dE_gen_header_in_up, dE_gen_header_in_down] = uncertainty_E_gen(I_curr,mean(T_m(:,1)),mean(rho_e(:,1)),L_header,Th_B*W_header,Inconel_rho_e,E_gen_header_in);
E_gen_header_out = I_curr^2 * L_header * mean(rho_e(:,end))/(Th_B*W_header);
[dE_gen_header_out_up, dE_gen_header_out_down] = uncertainty_E_gen(I_curr,mean(T_m(:,end)),mean(rho_e(:,end)),L_header,Th_B*W_header,Inconel_rho_e,E_gen_header_out);


%%
%Equations
q_rad = zeros(N_nodes_cross,N_nodes);     %Heat transfer by radiation
q_conv = zeros(N_nodes_cross,N_nodes);    %Heat transfer by convection
h_conv = zeros(N_nodes_cross,N_nodes);  %Convective heat transfer coefficient
dq_rad_up = zeros(N_nodes_cross,N_nodes); %Upper error on heat exchanged by radiation due to the different measurement errors
dq_rad_down = zeros(N_nodes_cross,N_nodes);%Lower error on heat exchanged by radiation due to the different measurement errors
dq_conv_up = zeros(N_nodes_cross,N_nodes);%Upper error on heat exchanged by convection due to the different measurement errors
dq_conv_down = zeros(N_nodes_cross,N_nodes); %Lower error on heat exchanged by convection due to the different measurement errors
dh_conv_up = zeros(N_nodes_cross,N_nodes); %Upper error on the convective heat transfer coefficient due to the different measurement errors
dh_conv_down = zeros(N_nodes_cross,N_nodes);%Lower error on the convective heat transfer coefficient due to the different measurement errors

for i = 1: N_nodes
    %Heat exchange is computed for all the channel points
    for j = 1: N_nodes_cross
        q_rad(j,i)= epsilon * sigma * dx * dy * ((T_m(j,i)+273.15)^4 - (T_inf+273.15)^4);
        q_conv(j,i) = E_gen(j,i) - q_rad(j,i) +4/3*E_gen_sw(i)/N_nodes_cross; 
        [dq_rad_up(j,i), dq_rad_down(j,i)] = uncertainty_q_rad(T_m(j,i), epsilon, sigma, dx, dy, T_inf, q_rad(j,i));
         dq_conv_up(j,i) = sqrt(dE_gen_up(j,i)^2 +  dq_rad_up(j,i)^2 + (4/3*dE_gen_sw_up(i)/N_nodes_cross)^2);
        dq_conv_down(j,i) = sqrt(dE_gen_down(j,i)^2 +  dq_rad_down(j,i)^2 + (4/3*dE_gen_sw_down(i)/N_nodes_cross)^2);
    end
    
    %Energy conservation
    %First the enthalpy is computed and then the temperature is computed using
    %Coolprop. The '-' sign is used as the convective heat transfer is
    %computed with regard to the solid and not the fluid.
    if i == 1
        h_F0 = (m_dot_chan * N_ch *h_F_in + E_gen_header_in)/(m_dot_chan * N_ch);
        [dh_F0_up, dh_F0_down] = uncertainty_h_bo(m_dot_chan * N_ch,h_F0,h_F_in,dh_F_in_up,dh_F_in_down,E_gen_header_in,dE_gen_header_in_up, dE_gen_header_in_down);
        T_F0 =CoolProp.PropsSI('T', 'H', h_F0, 'P', P_sCO2, fluid)-273.15;
        h_F(i) = (m_dot_chan * h_F0 + sum(q_conv(:,i)) )/m_dot_chan;
        [dh_F_up(i), dh_F_down(i)] = uncertainty_h(m_dot_chan,h_F(i),h_F0,dh_F0_up,dh_F0_down,E_gen(:,i),dE_gen_up(:,i), dE_gen_down(:,i),E_gen_sw(i),dE_gen_sw_up(i),dE_gen_sw_down(i),q_rad(:,i),dq_rad_up(:,i), dq_rad_down(:,i));
    else
        h_F(i) = (m_dot_chan * h_F(i-1) + sum(q_conv(:,i)))/m_dot_chan;
        [dh_F_up(i), dh_F_down(i)] = uncertainty_h(m_dot_chan,h_F(i),h_F(i-1),dh_F_up(i-1),dh_F_down(i-1),E_gen(:,i),dE_gen_up(:,i), dE_gen_down(:,i),E_gen_sw(i),dE_gen_sw_up(i),dE_gen_sw_down(i),q_rad(:,i),dq_rad_up(:,i), dq_rad_down(:,i));
    end
    T_F(i) =CoolProp.PropsSI('T', 'H', h_F(i), 'P', P_sCO2, fluid)-273.15;
    [dT_F_up(i),dT_F_down(i)] = uncertainty_T_F(T_F(i),h_F(i),dh_F_up(i), dh_F_down(i),P_sCO2,fluid);
    mu_b(i) = CoolProp.PropsSI('viscosity', 'T', T_F(i)+273.15, 'P', P_sCO2, fluid); %Dynamic viscosity at the bulk temperature
    Re_b(i) = (G_chan*D_h)/mu_b(i);                                           %Reynolds number
    
    h_conv(:,i) = q_conv(:,i)./(dx*dy*(T_m(:,i)-T_F(i)));
    for j = 1: N_nodes_cross
        [dh_conv_up(j,i),dh_conv_down(j,i)] = uncertainty_h_conv(h_conv(j,i),q_conv(j,i),dq_conv_up(j,i),dq_conv_down(j,i),T_m(j,i),T_F(i),dT_F_up(i),dT_F_down(i),dx,dy);
        [Bo_star(j,i),K_v(j,i)] = buoyancy_acc(T_m(j,i),T_F(i),P_sCO2,fluid,E_gen(j,i)+4/3*E_gen_sw(i)/N_nodes_cross,dx,dy,D_h,G_chan,per,W_ch);
    end
    
end

h_F_out_calc = (m_dot_chan * N_ch * h_F(end) + E_gen_header_out)/(m_dot_chan * N_ch);
[dh_F_out_up, dh_F_out_down] = uncertainty_h_bo(m_dot_chan * N_ch,h_F_out_calc,h_F(end),dh_F_up(end),dh_F_down(end),E_gen_header_out,dE_gen_header_out_up, dE_gen_header_out_down);
T_F_out_calc =CoolProp.PropsSI('T', 'H', h_F_out_calc, 'P', P_sCO2, fluid)-273.15;
[dT_F_out_calc_up,dT_F_out_calc_down] = uncertainty_T_F(T_F_out_calc,h_F_out_calc,dh_F_out_up, dh_F_out_down,P_sCO2,fluid);

E_gen_tot = E_gen_header_in + E_gen_header_out + sum(E_gen_sw)*4 + sum(sum(E_gen))*3;
Q_dot =  E_gen_tot/(W_header*((L_header*2)+L_B));

%% Figures
T_R = (T_F+273.15)/(T_PC+273.15);
x = (0:dy:(length(mean(h_conv))-1)*dy)*1000;
figure
a = mean(h_conv);
a1 = mean(dh_conv_down);
a2 = mean(dh_conv_up);
errorbar(x(1:2:end),a(1:2:end),a2(1:2:end),a2(1:2:end),'o') %'LineStyle','none'
grid
xlabel('Axial distance (mm)')%T_{bulk}/T_{PC}
ylabel('Heat transfer coefficient (W/m^2K)')

figure
errorbar(x(1:2:end),T_F(1:2:end),dT_F_down(1:2:end),dT_F_up(1:2:end),'o') 
hold on
errorbar(((L_header)+L_B)*1000,T_F_out_calc,dT_F_out_calc_down,dT_F_out_calc_up,'o')
fplot(T_F_in)
fplot(T_F_out)
fplot(T_PC,':')
legend('Computed temperature','T_{out} (computed)','T_{in}','T_{out}','T_{PC}')
axis([0 58 (T_F_in-1) (T_F_out+4)])
grid
xlabel('Axial distance (mm)')%T_{bulk}/T_{PC}
ylabel('Fluid temperature (C)')


figure
error_T_m = zeros(1,length(mean(T_m)));
error_T_m(:) = 2;
b = mean(T_m);
errorbar(x(1:2:end),b(1:2:end),error_T_m(1:2:end),error_T_m(1:2:end),'o')
grid
xlabel('Axial distance (mm)')%T_{bulk}/T_{PC}
ylabel('Plate temperature (C)')

figure
c = mean(Bo_star);
d = mean(K_v);
yyaxis left
plot(x(1:2:end),c(1:2:end),'o')
ylabel('Gr_q/Gr_{th}')
yyaxis right
plot(x(1:2:end),d(1:2:end),'o')
ylabel('K_v')
legend('Buoyancy criterion (threshold value: 1)','Acceleration crtierion (threshold value: 9.5*10^{-7})')
grid
xlabel('Axial distance (mm)')%T_{bulk}/T_{PC}
