run convective_analysis
T_surf_av = mean(T_m)+273.15;		%Average surface temperature - measured
T_F_K = T_F+273.15;
T_PC_K = T_PC +273.15;
RR_channel = R_a/D_h;
T_av = mean([T_F_K;T_surf_av]);

rho_wall = zeros(1,N_nodes);
rho_bulk = zeros(1,N_nodes);
Pr_bulk = zeros(1,N_nodes);
Pr_wall = zeros(1,N_nodes);
Pr_av = zeros(1,N_nodes);
Pr_min = zeros(1,N_nodes);
k_bulk = zeros(1,N_nodes);
k_wall = zeros(1,N_nodes);
cp_bulk = zeros(1,N_nodes);
h_bulk = zeros(1,N_nodes);
h_wall = zeros(1,N_nodes);
Theta_1 = zeros(1,N_nodes);
Theta_2 = zeros(1,N_nodes); 
f_Churchill_channel = zeros(1,N_nodes);
f_fd = zeros(1,N_nodes);
V_chan_b = zeros(1,N_nodes);
delta_P_b = zeros(1,N_nodes);
V_chan_w = zeros(1,N_nodes);
delta_P_w = zeros(1,N_nodes);

Nuss_gn = zeros(1,N_nodes);
alpha_gn = zeros(1,N_nodes);
dalpha_up = zeros(1,N_nodes);
dalpha_down = zeros(1,N_nodes);

Nu_orn = zeros(1,N_nodes);
h_orn = zeros(1,N_nodes);
q_wall_orn = zeros(1,N_nodes);
dh_orn_up = zeros(1,N_nodes);
dh_orn_down = zeros(1,N_nodes);

Nu_miro = zeros(1,N_nodes);
h_miro = zeros(1,N_nodes);
q_wall_miro = zeros(1,N_nodes);
dh_miro_up = zeros(1,N_nodes);
dh_miro_down = zeros(1,N_nodes);

n_val_JH = zeros(1,N_nodes);
Nu_JandH = zeros(1,N_nodes);
cp_bar = zeros(1,N_nodes);
h_JandH = zeros(1,N_nodes);
q_wall_JandH = zeros(1,N_nodes);
dh_JandH_up = zeros(1,N_nodes);
dh_JandH_down = zeros(1,N_nodes);


for i = 1:N_nodes
    rho_wall(i) = CoolProp.PropsSI('D', 'T', T_surf_av(i), 'P', P_sCO2, fluid);%Density at the wall temperature
    rho_bulk(i) = CoolProp.PropsSI('D', 'T', T_F_K(i), 'P', P_sCO2, fluid);   %Density at the bulk temperature
    Pr_bulk(i) = CoolProp.PropsSI('Prandtl', 'T', T_F_K(i), 'P', P_sCO2, fluid);%Prandtl number at the bulk temperature
    Pr_wall(i) = CoolProp.PropsSI('Prandtl', 'T', T_surf_av(i), 'P', P_sCO2, fluid);%Prandtl number at the wall temperature
    Pr_av(i) = CoolProp.PropsSI('Prandtl', 'T', T_av(i), 'P', P_sCO2, fluid);%Prandtl number at the wall temperature
    Pr_min(i) = min(Pr_bulk(i),Pr_wall(i));                                               %Minimum Prandtl number
    k_bulk(i) = CoolProp.PropsSI('conductivity', 'T', T_F_K(i), 'P', P_sCO2, fluid);%Thermal onductivity at the bulk temperature
    k_wall(i) = CoolProp.PropsSI('conductivity', 'T', T_surf_av(i), 'P', P_sCO2, fluid);		%Conductivity of the fluid
    cp_bulk(i) = CoolProp.PropsSI('C', 'T', T_F_K(i), 'P', P_sCO2, fluid);%Specific heat at constant pressure at the bulk temperature
    h_bulk(i) =  CoolProp.PropsSI('H', 'T', T_F_K(i), 'P', P_sCO2, fluid);%Density at the wall temperature
    h_wall(i) =  CoolProp.PropsSI('H', 'T', T_surf_av(i), 'P', P_sCO2, fluid);%Density at the wall temperature

    
    %Pressure losses    
    Theta_1(i)=(2.457*log(((7/Re_b(i))^0.9+0.27*RR_channel)^(-1)))^16;
    Theta_2(i)=(37530/Re_b(i))^16;
    f_Churchill_channel(i)=8*((8/Re_b(i))^(12)+(Theta_1(i)+Theta_2(i))^(-1.5))^(1/12);               %" Darcy factor from the Churchill correlation"
    
    f_fd(i) = f_Churchill_channel(i);
    
    V_chan_b(i) = G_chan/rho_bulk(i);
    delta_P_b(i) = f_fd(i)*L_B/D_h * V_chan_b(i)^2/2 * rho_bulk(i);
    
    V_chan_w(i) = G_chan/rho_wall(i);
    delta_P_w(i) = f_fd(i)*L_B/D_h * V_chan_w(i)^2/2 * rho_wall(i);
    
    
    %Dittus-Boelter correlation 
    Nuss_gn(i) = 0.023*Re_b(i)^0.8*Pr_bulk(i)^0.4*0.91;       
    
    alpha_gn(i) = (Nuss_gn(i)*k_bulk(i))/D_h;
    [dalpha_up(i),dalpha_down(i)] = uncertainty_alpha(T_F_K(i),dT_F_up(i),dT_F_down(i),P_sCO2,G_chan,D_h,alpha_gn(i),fluid);
    
    
    % Ornastsky  correlation 1970
    Nu_orn(i) = 0.023*Re_b(i)^(0.8)*Pr_min(i)^(0.8)*(rho_wall(i)/rho_bulk(i))^(0.3);          %ORNATSKY ET AL. (1970) Correlation
    h_orn(i) = (Nu_orn(i)*k_bulk(i))/D_h;                                                %Heat transfer coefficient
    q_wall_orn(i) = h_orn(i)*dy*W_ch*(T_surf_av(i)-T_F_K(i));
    [dh_orn_up(i),dh_orn_down(i)] = uncertainty_h_orn(T_F_K(i),dT_F_up(i),dT_F_down(i),T_surf_av(i),P_sCO2,G_chan,Re_b(i),D_h,h_orn(i),fluid);
    
    
    
    %Miropolski correlation
    Nu_miro(i) = 0.023*Re_b(i)^(0.8)*Pr_min(i)^(0.8);               %MIROPOLSKI AND SHITSMAN (1958)
    h_miro(i) = (Nu_miro(i)*k_bulk(i))/D_h ;                                  %Heat transfer coefficient
    q_wall_miro(i) = h_miro(i)*dy*W_ch*(T_surf_av(i)-T_F_K(i));
    [dh_miro_up(i),dh_miro_down(i)] = uncertainty_h_miro(T_F_K(i),dT_F_up(i),dT_F_down(i),T_surf_av(i),P_sCO2,G_chan,Re_b(i),D_h,h_miro(i),fluid);
   
    
    %Jackson and Hall (1979) correlation
    %Defining the value of the power when the bulk temperature/wall temperature pair are below or above the pseudocritical temperature
    if ((T_F_K(i) < T_surf_av(i)) && (T_surf_av(i) < T_PC_K)) || ((1.2*T_PC_K < T_F_K(i)) && ( T_F_K(i) < T_surf_av(i)))
        n_val_JH(i) = 0.4;
    end
    
    %Defining the value of the power when the pseudocritical temperature is between the bulk and wall temperature, i.e. within the boundary layer
    if ((T_F_K(i) < T_PC_K) && (T_PC_K< T_surf_av(i)))
        n_val_JH(i) = 0.4 + 0.2*((T_surf_av(i)/T_PC_K)-1);
    end
    
    %Defining the value of the power the bulk is within a certain quantity (1.2 times) near the pseudocritical temperature
    if ((T_PC_K < T_F_K(i)) && (T_F_K(i) < 1.2*T_PC_K)) && ((T_F_K(i) < T_surf_av(i)))
        n_val_JH(i) = 0.4 + 0.2*((T_surf_av(i)/T_PC_K)-1)*(1-5*((T_F_K(i)/T_PC_K)-1));
    else
        n_val_JH(i) = 0.4;
    end
    
    A = h_wall(i)-h_bulk(i);
    B = T_surf_av(i)-T_F_K(i);
    cp_bar(i) = (A)/(B);
    Nu_JandH(i) = 0.0183*Re_b(i)^(0.82)*Pr_bulk(i)^(0.5)*(rho_wall(i)/rho_bulk(i))^(0.3)*(cp_bar(i)/cp_bulk(i))^(n_val_JH(i));
    h_JandH(i) = (Nu_JandH(i)*k_bulk(i))/D_h;
    q_wall_JandH(i) = h_JandH(i)*dy*W_ch*(T_surf_av(i)-T_F_K(i));
    [dh_JandH_up(i),dh_JandH_down(i)] = uncertainty_h_JandH(T_F_K(i),dT_F_up(i),dT_F_down(i),T_surf_av(i),P_sCO2,G_chan,Re_b(i),D_h,h_JandH(i),n_val_JH(i),fluid);
end
delta_P_tot_b = sum(delta_P_b);
delta_P_tot_w = sum(delta_P_w);

h_conv_m = mean(h_conv);
MAPE_DB =  100/(N_nodes-39)*sum((h_conv_m(20:end-20)-alpha_gn(20:end-20))./h_conv_m(20:end-20)) %Mean absolute percent error for the Dittus-Boleter correlation
MAPE_miro =  100/(N_nodes-39)*sum((h_conv_m(20:end-20)-h_miro(20:end-20))./h_conv_m(20:end-20)) %Mean absolute percent error for the Miropolski correlation
MAPE_orn = 100/(N_nodes-39)*sum((h_conv_m(20:end-20)-h_orn(20:end-20))./h_conv_m(20:end-20)) %Mean absolute percent error for the Ornastsky correlation
MAPE_JandH = 100/(N_nodes-39)*sum((h_conv_m(20:end-20)-h_JandH(20:end-20))./h_conv_m(20:end-20)) %Mean absolute percent error for the Jackson and Hall correlation
%%
figure %this figure can either be plotted with the error of the experimental results alone or with the error of all correlations.
errorbar(x(1:2:end),a(1:2:end),a2(1:2:end),a2(1:2:end),'o') %'LineStyle','none'
hold on
%plot(x(1:2:end),alpha_gn(1:2:end),'o')
plot(x(1:2:end),h_miro(1:2:end),'o')
plot(x(1:2:end),h_orn(1:2:end),'o')
plot(x(1:2:end),h_JandH(1:2:end),'o')
% errorbar(x(1:2:end),alpha_gn(1:2:end),dalpha_down(1:2:end),dalpha_up(1:2:end),'o')
% errorbar(x(1:2:end),h_orn(1:2:end),dh_orn_down(1:2:end),dh_orn_up(1:2:end),'o')
% errorbar(x(1:2:end),h_miro(1:2:end),dh_miro_down(1:2:end),dh_miro_up(1:2:end),'o')
% errorbar(x(1:2:end),h_JandH(1:2:end),dh_JandH_down(1:2:end),dh_JandH_up(1:2:end),'o')
Leg_DB = sprintf('Dittus-Boelter: MAPE = %.1f%%',MAPE_DB);
Leg_miro = sprintf('Miropolski: MAPE = %.1f%%',MAPE_miro);
Leg_orn = sprintf('Ornatsky: MAPE = %.1f%%',MAPE_orn);
Leg_JandH = sprintf('Jackson: MAPE = %.1f%%',MAPE_JandH);
legend('Data analysis',Leg_miro,Leg_orn,Leg_JandH)%,Leg_DB


