%This function compute the upper and lower uncertainty error over the
%computation of the fluid enthalpy depending on the mass flow m_dot, the
%enthalpy of the node h and of the previous node h0 (with its errors dh),
%and the heat generated E_gen (with its errors dE)
function [dh_bo_up, dh_bo_down] = uncertainty_h_bo(m_dot,h,h0,dh_up0,dh_down0,E_gen,dE_gen_up,dE_gen_down)
error_m_dot = 5.4167e-05 + 0.001*m_dot;

%dh_up calculation
d_m_dot_up = ((m_dot+error_m_dot) * h0 + E_gen)/(m_dot+error_m_dot) - h;
d_h0_up = (m_dot * (h0+dh_up0) + E_gen )/m_dot - h;
d_E_gen_up = (m_dot * h0 + E_gen + dE_gen_up )/m_dot - h;

dh_bo_up = sqrt(d_m_dot_up^2 + d_h0_up^2 + d_E_gen_up^2 );


%dh_down calculation
d_m_dot_down = ((m_dot-error_m_dot) * h0 + E_gen)/(m_dot-error_m_dot) - h;
d_h0_down = (m_dot * (h0-dh_down0) + E_gen )/m_dot - h;
d_E_gen_down = (m_dot * h0 + E_gen - dE_gen_down )/m_dot - h;

dh_bo_down = sqrt(d_m_dot_down^2 + d_h0_down^2 + d_E_gen_down^2 );
end